@@ -31,51 +31,86 @@
 # STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 # THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
-from adi.ad936x import *
+from adi.ad936x import ad9361, ad9363, ad9364, Pluto
 
-from adi.fmcomms5 import *
+from adi.fmcomms5 import FMComms5
 
-from adi.ad9371 import *
+from adi.ad9371 import ad9371
 
 from adi.adrv9002 import adrv9002
 
-from adi.adrv9009 import *
+from adi.adrv9009 import adrv9009
 
-from adi.adrv9009_zu11eg import *
+from adi.adrv9009_zu11eg import adrv9009_zu11eg
 
-from adi.adrv9009_zu11eg_multi import *
+from adi.adrv9009_zu11eg_multi import adrv9009_zu11eg_multi
 
-from adi.adrv9009_zu11eg_fmcomms8 import *
+from adi.adrv9009_zu11eg_fmcomms8 import adrv9009_zu11eg_fmcomms8
 
-from adi.ad9680 import *
+from adi.ad9081 import ad9081
 
-from adi.ad9144 import *
+from adi.ad9081_mc import ad9081_mc, QuadMxFE
 
-from adi.ad9152 import *
+from adi.ad9083 import ad9083
 
-from adi.cn0532 import *
+from adi.ad9094 import ad9094
 
-from adi.daq2 import *
+from adi.ad9680 import ad9680
 
-from adi.daq3 import *
+from adi.ad9136 import ad9136
 
-from adi.adis16460 import *
+from adi.ad9144 import ad9144
 
-from adi.adis16507 import *
+from adi.ad9152 import ad9152
 
-from adi.ad7124 import *
+from adi.cn0532 import cn0532
 
-from adi.adxl345 import *
+from adi.daq2 import DAQ2
 
-from adi.fmclidar1 import *
+from adi.daq3 import DAQ3
 
-from adi.jesd import *
+from adi.adis16460 import adis16460
 
-from adi.ad5686 import *
+from adi.adis16495 import adis16495
 
-from adi.adar1000 import adar1000
+from adi.adis16507 import adis16507
 
-from adi.ltc2983 import *
+from adi.ad7124 import ad7124
 
-__version__ = "0.0.6"
+from adi.adxl345 import adxl345
+
+from adi.adxrs290 import adxrs290
+
+from adi.fmclidar1 import fmclidar1
+
+from adi.ad5686 import ad5686
+
+from adi.adar1000 import adar1000, adar1000_array
+
+from adi.ltc2983 import ltc2983
+
+from adi.one_bit_adc_dac import one_bit_adc_dac
+
+from adi.ltc2314_14 import ltc2314_14
+
+from adi.ad7606 import ad7606
+
+from adi.ad7799 import ad7799
+
+from adi.ad7746 import ad7746
+
+from adi.adpd410x import adpd410x
+
+from adi.ad7689 import ad7689
+
+from adi.adf4371 import adf4371
+
+from adi.adpd188 import adpd188
+
+try:
+    from adi.jesd import jesd
+except ImportError:
+    pass
+
+__version__ = "0.0.9"
 name = "Analog Devices Hardware Interfaces"
