@@ -48,7 +48,7 @@ class phy(attribute):
 
 
 class rx(attribute):
-    """ Buffer handling for receive devices """
+    """Buffer handling for receive devices"""
 
     _rxadc: iio.Device = []
     _rx_channel_names: List[str] = []
@@ -89,6 +89,8 @@ class rx(attribute):
 
     @rx_enabled_channels.setter
     def rx_enabled_channels(self, value):
+        if not value:
+            raise Exception("rx_enabled_channels cannot be empty")
         if self._complex_data:
             if max(value) > ((self._num_rx_channels) / 2 - 1):
                 raise Exception("RX mapping exceeds available channels")
@@ -183,11 +185,35 @@ class rx(attribute):
             return sig[0]
         return sig
 
+    def __multi_type_rx(self, data):
+        """Process buffers with multiple data types"""
+        # Process each channel at a time
+        channel_bytes = []
+        curated_rx_type = []
+        for en_ch in self.rx_enabled_channels:
+            channel_bytes += [np.dtype(self._rx_data_type[en_ch]).itemsize]
+            curated_rx_type += [self._rx_data_type[en_ch]]
+        offset = 0
+        stride = sum(channel_bytes)
+        sig = []
+        for indx, chan_bytes in enumerate(channel_bytes):
+            bar = bytearray()
+            for bytesI in range(offset, len(data), stride):
+                bar.extend(data[bytesI : bytesI + chan_bytes])
+
+            sig.append(np.frombuffer(bar, dtype=curated_rx_type[indx]))
+            offset += chan_bytes
+        return sig
+
     def __rx_non_complex(self):
         if not self.__rxbuf:
             self._rx_init_channels()
         self.__rxbuf.refill()
         data = self.__rxbuf.read()
+
+        if isinstance(self._rx_data_type, list):
+            return self.__multi_type_rx(data)
+
         x = np.frombuffer(data, dtype=self._rx_data_type)
         if self._rx_mask != 0:
             x = np.bitwise_and(x, self._rx_mask)
@@ -235,13 +261,13 @@ class rx(attribute):
         return sig
 
     def rx(self):
-        """ Receive data from hardware buffers for each channel index in
-            rx_enabled_channels.
+        """Receive data from hardware buffers for each channel index in
+        rx_enabled_channels.
 
-            returns: type=numpy.array or list of numpy.array
-                An array or list of arrays when more than one receive channel
-                is enabled containing samples from a channel or set of channels.
-                Data will be complex when using a complex data device.
+        returns: type=numpy.array or list of numpy.array
+            An array or list of arrays when more than one receive channel
+            is enabled containing samples from a channel or set of channels.
+            Data will be complex when using a complex data device.
         """
         if self._rx_unbuffered_data:
             return self.__rx_unbuffered_data()
@@ -253,7 +279,7 @@ class rx(attribute):
 
 
 class tx(dds, attribute):
-    """ Buffer handling for transmit devices """
+    """Buffer handling for transmit devices"""
 
     _tx_buffer_size = 1024
     _txdac: iio.Device = []
@@ -300,6 +326,9 @@ class tx(dds, attribute):
 
     @tx_enabled_channels.setter
     def tx_enabled_channels(self, value):
+        if not value:
+            self.__tx_enabled_channels = value
+            return
         if self._complex_data:
             if max(value) > ((self._num_tx_channels) / 2 - 1):
                 raise Exception("TX mapping exceeds available channels")
@@ -327,15 +356,28 @@ class tx(dds, attribute):
             self._txdac, self._tx_buffer_size, self.__tx_cyclic_buffer
         )
 
-    def tx(self, data_np):
-        """ Transmit data to hardware buffers for each channel index in
-            tx_enabled_channels.
+    def tx(self, data_np=None):
+        """Transmit data to hardware buffers for each channel index in
+        tx_enabled_channels.
 
-            args: type=numpy.array or list of numpy.array
-                An array or list of arrays when more than one transmit channel
-                is enabled containing samples from a channel or set of channels.
-                Data must be complex when using a complex data device.
+        args: type=numpy.array or list of numpy.array
+            An array or list of arrays when more than one transmit channel
+            is enabled containing samples from a channel or set of channels.
+            Data must be complex when using a complex data device.
         """
+        if not self.__tx_enabled_channels and data_np:
+            raise Exception(
+                "When tx_enabled_channels is None or empty,"
+                + " the input to tx() must be None or empty or not provided"
+            )
+        if not self.__tx_enabled_channels:
+            # Set TX DAC to zero source
+            for chan in self._txdac.channels:
+                if chan.output:
+                    chan.attrs["raw"].value = "0"
+                    return
+            raise Exception("No DDS channels found for TX, TX zeroing does not apply")
+
         if self.__txbuf and self.tx_cyclic_buffer:
             raise Exception(
                 "TX buffer has been submitted in cyclic mode. "
